from distutils.core import setup
from os import path
this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()
setup(
  name = 'harpies',
  packages = ['harpies'],
  version = '1.0.0',
  license='MIT',
  description = 'Helps you generating link previews on the fly!',
  long_description=long_description,
  long_description_content_type='text/rst',
  author = 'S M Mahmudul Hasan',
  author_email = 'thegeek@iamlizu.com',
  url = 'https://iamlizu.com/tools/harpies/',
  download_url = 'https://github.com/IamLizu/harpies/archive/v_1_0_0.tar.gz',
  keywords = ['url', 'link', 'preview'],
  classifiers=[
    'Development Status :: 5 - Production/Stable',
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
  ],
)


import sys
import os
import uraiko
from bs4 import BeautifulSoup
import requests
import json
import logging

logger = logging.getLogger(__name__)
logger.setLevel(logging.INFO)

formatter = logging.Formatter('%(asctime)s:%(levelname)s:%(name)s:%(message)s')

log_file = os.path.join(os.path.normpath(os.path.expanduser('~/Documents/')), 'harpies.log')

file_handler = logging.FileHandler(log_file)
file_handler.setFormatter(formatter)

logger.addHandler(file_handler)

def preview_data(link):
    logger.info("Checking " + link)
    uLink = uraiko.url_check(link)
    logger.info("Downloading the html page")

    response = requests.get(uLink)
    logger.info("Parsing the html page")
    soup = BeautifulSoup(response.text, "html.parser")

    logger.info("Saving meta datas into variables")
    metaTitle = soup.find("meta", property="og:title")["content"]
    metaDes = soup.find("meta", property="og:description")["content"]
    metaImg = soup.find("meta", property="og:image")["content"]
    metaUrl = soup.find("meta", property="og:url")["content"]

    logger.info("creating json object with data")
    metas = {
        "title": metaTitle,
        "description": metaDes,
        "image": metaImg,
        "url": metaUrl
        }
    
    metaJson = json.dumps(metas)

    return metaJson